

import sys
import re
import os
import csv
import json


lang = sys.argv[1]


def normalize(txt):
    txt = re.sub(r'\s*,\s*', ',', txt)
    txt = re.sub(r'\s*\.\s*', '.', txt)
    return txt


modes = ['train', 'dev', 'test']

annotations = []
with open(lang + '.json', 'r') as fp:
    lines = fp.readlines()
    annotations = map(lambda l: json.loads(l), lines)
    annotations = list(annotations)

translations = {}
for line in annotations:
    if line['content'].startswith('"'):
        line['content'] = line['content'][1:-1].replace('""', '"')
    splits = line['content'].split('|')
    if splits[1] in translations and translations[splits[1]] != splits[2]:
        raise Exception('Broke')
    translations[normalize(splits[1])] = splits[2]

os.makedirs(lang)

for mode in modes:
    tdata = [['index', 'sentence1', 'sentence2', 'label']]
    with open('../WNLI/{}.tsv'.format(mode), 'r') as fp:
        reader = csv.reader(fp, delimiter='\t')
        data = list(reader)[1:]
    for inst in data:
        if len(inst) == 0:
            continue
        tinst = [inst[0], translations[normalize(inst[1])], translations[normalize(inst[2])]]
        if mode != 'test':
            tinst.append(inst[3])
        tdata.append(tinst)
    with open('{}/{}.csv'.format(lang, mode), 'w') as fp:
        writer = csv.writer(fp, delimiter=',')
        for line in tdata:
            writer.writerow(line)
